<?php
/**
 * Video Podcasting Theme Customizer
 *
 * @package Video Podcasting
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function video_podcasting_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'video_podcasting_custom_controls' );

function video_podcasting_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'video_podcasting_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'video_podcasting_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'video_podcasting_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'video-podcasting' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'video_podcasting_left_right', array(
    	'title' => esc_html__( 'General Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_panel_id'
	) );

	$wp_customize->add_setting('video_podcasting_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control(new Video_Podcasting_Image_Radio_Control($wp_customize, 'video_podcasting_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','video-podcasting'),
        'description' => esc_html__('Here you can change the width layout of Website.','video-podcasting'),
        'section' => 'video_podcasting_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('video_podcasting_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control('video_podcasting_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','video-podcasting'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','video-podcasting'),
        'section' => 'video_podcasting_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','video-podcasting'),
            'Right Sidebar' => esc_html__('Right Sidebar','video-podcasting'),
            'One Column' => esc_html__('One Column','video-podcasting'),
            'Grid Layout' => esc_html__('Grid Layout','video-podcasting')
        ),
	) );

	$wp_customize->add_setting('video_podcasting_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control('video_podcasting_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','video-podcasting'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','video-podcasting'),
        'section' => 'video_podcasting_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','video-podcasting'),
            'Right_Sidebar' => esc_html__('Right Sidebar','video-podcasting'),
            'One_Column' => esc_html__('One Column','video-podcasting')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'video_podcasting_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'video_podcasting_customize_partial_video_podcasting_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'video_podcasting_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','video-podcasting' ),
		'section' => 'video_podcasting_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'video_podcasting_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'video_podcasting_customize_partial_video_podcasting_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'video_podcasting_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','video-podcasting' ),
		'section' => 'video_podcasting_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'video_podcasting_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','video-podcasting' ),
        'section' => 'video_podcasting_left_right'
    )));

	$wp_customize->add_setting('video_podcasting_preloader_bg_color', array(
		'default'           => '#222222',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'video_podcasting_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'video-podcasting'),
		'section'  => 'video_podcasting_left_right',
	)));

	$wp_customize->add_setting('video_podcasting_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'video_podcasting_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'video-podcasting'),
		'section'  => 'video_podcasting_left_right',
	)));

	// Header
	$wp_customize->add_section( 'video_podcasting_header' , array(
    	'title' => esc_html__( 'Header', 'video-podcasting' ),
		'panel' => 'video_podcasting_panel_id'
	) );

	$wp_customize->add_setting('video_podcasting_donate_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_donate_btn_text',array(
		'label'	=> esc_html__('Add Button Text','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Donate', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_header',
		'type'=> 'text'
	));

	$wp_customize->add_setting('video_podcasting_donate_btn_url',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('video_podcasting_donate_btn_url',array(
		'label'	=> esc_html__('Add Button URL','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example.com', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_header',
		'type'=> 'url'
	));

	//Slider
	$wp_customize->add_section( 'video_podcasting_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_panel_id'
	) );

	$wp_customize->add_setting( 'video_podcasting_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ));  
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','video-podcasting' ),
      'section' => 'video_podcasting_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('video_podcasting_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'video_podcasting_customize_partial_video_podcasting_slider_hide_show',
	));

	for ( $count = 1; $count <= 3; $count++ ) {
		$wp_customize->add_setting( 'video_podcasting_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'video_podcasting_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'video_podcasting_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'video-podcasting' ),
			'description' => __('Slider image size (1500 x 600)','video-podcasting'),
			'section'  => 'video_podcasting_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//content layout
	$wp_customize->add_setting('video_podcasting_slider_content_option',array(
        'default' => 'Left',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control(new Video_Podcasting_Image_Radio_Control($wp_customize, 'video_podcasting_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','video-podcasting'),
        'section' => 'video_podcasting_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'video_podcasting_slider_excerpt_number', array(
		'default'              => 20,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'video_podcasting_sanitize_number_range'
	) );
	$wp_customize->add_control( 'video_podcasting_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','video-podcasting' ),
		'section'     => 'video_podcasting_slidersettings',
		'type'        => 'range',
		'settings'    => 'video_podcasting_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('video_podcasting_slider_opacity_color',array(
		'default'              => 0.7,
		'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));

	$wp_customize->add_control( 'video_podcasting_slider_opacity_color', array(
		'label'       => esc_html__( 'Slider Image Opacity','video-podcasting' ),
		'section'     => 'video_podcasting_slidersettings',
		'type'        => 'select',
		'settings'    => 'video_podcasting_slider_opacity_color',
		'choices' => array(
			'0' =>  esc_attr('0','video-podcasting'),
			'0.1' =>  esc_attr('0.1','video-podcasting'),
			'0.2' =>  esc_attr('0.2','video-podcasting'),
			'0.3' =>  esc_attr('0.3','video-podcasting'),
			'0.4' =>  esc_attr('0.4','video-podcasting'),
			'0.5' =>  esc_attr('0.5','video-podcasting'),
			'0.6' =>  esc_attr('0.6','video-podcasting'),
			'0.7' =>  esc_attr('0.7','video-podcasting'),
			'0.8' =>  esc_attr('0.8','video-podcasting'),
			'0.9' =>  esc_attr('0.9','video-podcasting')
		),
	));

	//Slider height
	$wp_customize->add_setting('video_podcasting_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_slider_height',array(
		'label'	=> __('Slider Height','video-podcasting'),
		'description'	=> __('Specify the slider height (px).','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'video_podcasting_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'video_podcasting_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','video-podcasting'),
		'section' => 'video_podcasting_slidersettings',
		'type'  => 'text',
	) );

	// About Section
	$wp_customize->add_section('video_podcasting_about_section',array(
		'title'	=> __('About Section','video-podcasting'),
		'description' => __('Add section title and Select the post to display for about.','video-podcasting'),
		'panel' => 'video_podcasting_panel_id',
	));

	$wp_customize->add_setting( 'video_podcasting_section_title', array(
		'default'           => '',
		'sanitize_callback' => 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'video_podcasting_section_title', array(
		'label'    => __( 'Add Section Title', 'video-podcasting' ),
		'input_attrs' => array(
            'placeholder' => __( 'About', 'video-podcasting' ),
        ),
		'section'  => 'video_podcasting_about_section',
		'type'     => 'text'
	) );

	$args =  array('numberposts' => -1);
	$post_list = get_posts($args);
	$i = 0;
	$psts[]='Select';  
	foreach($post_list as $post){
		$psts[$post->post_title] = $post->post_title;
	}

	$wp_customize->add_setting('video_podcasting_about_post',array(
		'default'	=> 'select',
		'sanitize_callback' => 'video_podcasting_sanitize_choices',
	));
	$wp_customize->add_control('video_podcasting_about_post',array(
		'type'    => 'select',
		'choices' => $psts,
		'label' => __('Select About Post','video-podcasting'),
		'section' => 'video_podcasting_about_section',
	));

	//Blog Post
	$wp_customize->add_panel( 'video_podcasting_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'video_podcasting_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_blog_post_parent_panel',
	));

	//Blog layout
    $wp_customize->add_setting('video_podcasting_blog_layout_option',array(
        'default' => 'Default',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
    ));
    $wp_customize->add_control(new Video_Podcasting_Image_Radio_Control($wp_customize, 'video_podcasting_blog_layout_option', array(
        'type' => 'select',
        'label' => __('Blog Post Layouts','video-podcasting'),
        'section' => 'video_podcasting_post_settings',
        'choices' => array(
            'Default' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout2.png',
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/blog-layout3.png',
    ))));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('video_podcasting_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'video_podcasting_Customize_partial_video_podcasting_toggle_postdate', 
	));

	$wp_customize->add_setting( 'video_podcasting_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','video-podcasting' ),
        'section' => 'video_podcasting_post_settings'
    )));

    $wp_customize->add_setting( 'video_podcasting_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_toggle_author',array(
		'label' => esc_html__( 'Author','video-podcasting' ),
		'section' => 'video_podcasting_post_settings'
    )));

    $wp_customize->add_setting( 'video_podcasting_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_toggle_comments',array(
		'label' => esc_html__( 'Comments','video-podcasting' ),
		'section' => 'video_podcasting_post_settings'
    )));

    $wp_customize->add_setting( 'video_podcasting_toggle_time',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_toggle_time',array(
		'label' => esc_html__( 'Time','video-podcasting' ),
		'section' => 'video_podcasting_post_settings'
    )));

    $wp_customize->add_setting( 'video_podcasting_featured_image_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
	));
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_featured_image_hide_show', array(
		'label' => esc_html__( 'Featured Image','video-podcasting' ),
		'section' => 'video_podcasting_post_settings'
    )));

    $wp_customize->add_setting( 'video_podcasting_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
	));
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_toggle_tags', array(
		'label' => esc_html__( 'Tags','video-podcasting' ),
		'section' => 'video_podcasting_post_settings'
    )));

    $wp_customize->add_setting( 'video_podcasting_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'video_podcasting_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'video_podcasting_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','video-podcasting' ),
		'section'     => 'video_podcasting_post_settings',
		'type'        => 'range',
		'settings'    => 'video_podcasting_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	$wp_customize->add_setting('video_podcasting_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','video-podcasting'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','video-podcasting'),
		'section'=> 'video_podcasting_post_settings',
		'type'=> 'text'
	));

    $wp_customize->add_setting('video_podcasting_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control('video_podcasting_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','video-podcasting'),
        'section' => 'video_podcasting_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','video-podcasting'),
            'Excerpt' => esc_html__('Excerpt','video-podcasting'),
            'No Content' => esc_html__('No Content','video-podcasting')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'video_podcasting_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'video_podcasting_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'video_podcasting_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'video_podcasting_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','video-podcasting' ),
		'section'     => 'video_podcasting_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('video_podcasting_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'video_podcasting_Customize_partial_video_podcasting_button_text', 
	));

    $wp_customize->add_setting('video_podcasting_button_text',array(
		'default'=> esc_html__('Read More','video-podcasting'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_button_text',array(
		'label'	=> esc_html__('Add Button Text','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'video_podcasting_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('video_podcasting_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'video_podcasting_Customize_partial_video_podcasting_related_post_title', 
	));

    $wp_customize->add_setting( 'video_podcasting_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ) );
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_related_post',array(
		'label' => esc_html__( 'Related Post','video-podcasting' ),
		'section' => 'video_podcasting_related_posts_settings'
    )));

    $wp_customize->add_setting('video_podcasting_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('video_podcasting_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'video_podcasting_sanitize_number_absint'
	));
	$wp_customize->add_control('video_podcasting_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_related_posts_settings',
		'type'=> 'number'
	));

	// Single Posts Settings
	$wp_customize->add_section( 'video_podcasting_single_blog_settings', array(
		'title' => __( 'Single Post Settings', 'video-podcasting' ),
		'panel' => 'video_podcasting_blog_post_parent_panel',
	));

	$wp_customize->add_setting('video_podcasting_single_post_meta_field_separator',array(
		'default'=> '|',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_single_post_meta_field_separator',array(
		'label'	=> __('Add Meta Separator','video-podcasting'),
		'description' => __('Add the seperator for meta box. Example: "|", "/", etc.','video-podcasting'),
		'section'=> 'video_podcasting_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('video_podcasting_single_blog_comment_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('video_podcasting_single_blog_comment_title',array(
		'label'	=> __('Add Comment Title','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => __( 'Leave a Reply', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('video_podcasting_single_blog_comment_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));

	$wp_customize->add_control('video_podcasting_single_blog_comment_button_text',array(
		'label'	=> __('Add Comment Button Text','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => __( 'Post Comment', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_single_blog_settings',
		'type'=> 'text'
	));

	$wp_customize->add_setting('video_podcasting_single_blog_comment_width',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('video_podcasting_single_blog_comment_width',array(
		'label'	=> __('Comment Form Width','video-podcasting'),
		'description'	=> __('Enter a value in %. Example:50%','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => __( '100%', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_single_blog_settings',
		'type'=> 'text'
	));

	//Responsive Media Settings
	$wp_customize->add_section('video_podcasting_responsive_media',array(
		'title'	=> esc_html__('Responsive Media','video-podcasting'),
		'panel' => 'video_podcasting_panel_id',
	));

    $wp_customize->add_setting( 'video_podcasting_resp_slider_hide_show',array(
      	'default' => 0,
     	'transport' => 'refresh',
      	'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ));  
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_resp_slider_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Slider','video-podcasting' ),
      	'section' => 'video_podcasting_responsive_media'
    )));

    $wp_customize->add_setting( 'video_podcasting_sidebar_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ));  
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_sidebar_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Sidebar','video-podcasting' ),
      	'section' => 'video_podcasting_responsive_media'
    )));

    $wp_customize->add_setting( 'video_podcasting_resp_scroll_top_hide_show',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ));  
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_resp_scroll_top_hide_show',array(
      	'label' => esc_html__( 'Show / Hide Scroll To Top','video-podcasting' ),
      	'section' => 'video_podcasting_responsive_media'
    )));

	//Footer Text
	$wp_customize->add_section('video_podcasting_footer',array(
		'title'	=> esc_html__('Footer Settings','video-podcasting'),
		'panel' => 'video_podcasting_panel_id',
	));	

	$wp_customize->add_setting( 'video_podcasting_hide_show_footer_credit_link',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ));  
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_hide_show_footer_credit_link',array(
      	'label' => esc_html__( 'Footer Credit Link','video-podcasting' ),
      	'section' => 'video_podcasting_footer'
    )));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('video_podcasting_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'video_podcasting_Customize_partial_video_podcasting_footer_text', 
	));
	
	$wp_customize->add_setting('video_podcasting_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('video_podcasting_footer_text',array(
		'label'	=> esc_html__('Copyright Text','video-podcasting'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2022, .....', 'video-podcasting' ),
        ),
		'section'=> 'video_podcasting_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('video_podcasting_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control(new Video_Podcasting_Image_Radio_Control($wp_customize, 'video_podcasting_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','video-podcasting'),
        'section' => 'video_podcasting_footer',
        'settings' => 'video_podcasting_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'video_podcasting_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'video_podcasting_switch_sanitization'
    ));  
    $wp_customize->add_control( new Video_Podcasting_Toggle_Switch_Custom_Control( $wp_customize, 'video_podcasting_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','video-podcasting' ),
      	'section' => 'video_podcasting_footer'
    )));

     //Selective Refresh
	$wp_customize->selective_refresh->add_partial('video_podcasting_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'video_podcasting_Customize_partial_video_podcasting_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('video_podcasting_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'video_podcasting_sanitize_choices'
	));
	$wp_customize->add_control(new Video_Podcasting_Image_Radio_Control($wp_customize, 'video_podcasting_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','video-podcasting'),
        'section' => 'video_podcasting_footer',
        'settings' => 'video_podcasting_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'video_podcasting_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Video_Podcasting_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Video_Podcasting_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Video_Podcasting_Customize_Section_Pro( $manager,'video_podcasting_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'Video Podcasting Pro', 'video-podcasting' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'video-podcasting' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/video-podcast-wordpress-theme/'),
		) )	);

		// Register sections.
		$manager->add_section(new Video_Podcasting_Customize_Section_Pro($manager,'video_podcasting_get_started_link',array(
			'priority'   => 1,
			'title'    => esc_html__( 'DOCUMENTATION', 'video-podcasting' ),
			'pro_text' => esc_html__( 'DOCS', 'video-podcasting' ),
			'pro_url'  => esc_url('https://www.vwthemesdemo.com/docs/free-video-podcasting/'),
		)));
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'video-podcasting-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'video-podcasting-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Video_Podcasting_Customize::get_instance();